UriRegistry
===========

[![image](https://badge.fury.io/py/uriregistry.png)](http://badge.fury.io/py/uriregistry)
[![image](https://readthedocs.org/projects/uriregistry/badge/?version=latest)](https://readthedocs.org/projects/uriregistry/?badge=latest)
[![image](https://travis-ci.org/OnroerendErfgoed/uriregistry.png?branch=master)](https://travis-ci.org/OnroerendErfgoed/uriregistry)
[![image](https://coveralls.io/repos/OnroerendErfgoed/uriregistry/badge.png?branch=master)](https://coveralls.io/r/OnroerendErfgoed/uriregistry)

This project aims to provide a central location for keeping track of
different resources through their URI\'s. It has been designed to answer
one simple question: in which applications is a certain resource (ie. a
URI) being used?
